@@ -28,13 +28,14 @@
 #include <QTimeLine>
 #include <QPainter>
 
-#include <KStandardDirs>
+
 #include <KConfig>
-#include <KDebug>
+#include <QDebug>
 #include <kconfiggroup.h>
 
 #include <KGamePopupItem>
 #include <KgTheme>
+#include <QStandardPaths>
 
 #include "molecule.h"
 #include "fielditem.h"
@@ -46,7 +47,7 @@ struct Theme : public KgTheme
 {
 	Theme() : KgTheme("pics/default_theme.desktop")
 	{
-		setGraphicsPath(KStandardDirs::locate("appdata", "pics/default_theme.svgz"));
+		setGraphicsPath(QStandardPaths::locate(QStandardPaths::DataLocation, "pics/default_theme.svgz"));
 	}
 };
 
@@ -56,7 +57,7 @@ PlayField::PlayField( QObject* parent )
     m_levelFinished(false)
 {
     m_atomTimeLine = new QTimeLine(300, this);
-    connect(m_atomTimeLine, SIGNAL(frameChanged(int)), SLOT(atomAnimFrameChanged(int)) );
+    connect(m_atomTimeLine, &QTimeLine::frameChanged, this, &PlayField::atomAnimFrameChanged);
 
     m_upArrow = new ArrowFieldItem(&m_renderer, Up, this);
     m_downArrow = new ArrowFieldItem(&m_renderer, Down, this);
@@ -86,7 +87,7 @@ void PlayField::setLevelData(const LevelData* level)
 {
     if (!level)
     {
-        kDebug() << "level data is null!";
+        //qDebug() << "level data is null!";
         return;
     }
 
@@ -124,7 +125,7 @@ void PlayField::updateFieldItems()
 {
     if (!m_levelData || !m_levelData->molecule())
     {
-        kDebug() << "level or molecule data is null!";
+        //qDebug() << "level or molecule data is null!";
         return;
     }
 
@@ -160,7 +161,7 @@ void PlayField::updateBackground()
 
 void PlayField::resize( int width, int height)
 {
-    kDebug() << "resize:" << width << "," << height;
+    //qDebug() << "resize:" << width << "," << height;
     setSceneRect( 0, 0, width, height );
 
     // we take 1/4 of width for displaying preview
@@ -177,7 +178,7 @@ void PlayField::resize( int width, int height)
     // if atom animation is running we need to rescale timeline
     if( isAnimating() )
     {
-        kDebug() << "restarting animation";
+        //qDebug() << "restarting animation";
         int curTime = m_atomTimeLine->currentTime();
         // calculate numCells to move using oldSize
         int numCells = m_atomTimeLine->endFrame()/oldSize;
@@ -573,7 +574,7 @@ bool PlayField::checkDone() const
 {
     if (!m_levelData || !m_levelData->molecule())
     {
-        kDebug() << "level or molecule data is null!";
+        //qDebug() << "level or molecule data is null!";
         return false;
     }
     // let's assume that molecule is done
@@ -608,7 +609,7 @@ bool PlayField::cellIsEmpty(int x, int y) const
 {
     if (!m_levelData)
     {
-        kDebug() << "level data is null!";
+        //qDebug() << "level data is null!";
         return true;
     }
 
@@ -676,7 +677,7 @@ void PlayField::drawForeground( QPainter *p, const QRectF&)
 {
     if (!m_levelData)
     {
-        kDebug() << "level data is null!";
+        //qDebug() << "level data is null!";
         return;
     }
 
@@ -767,11 +768,11 @@ QString PlayField::moleculeName() const
 {
     if (!m_levelData || !m_levelData->molecule())
     {
-        kDebug() << "level or molecule data is null!";
+        //qDebug() << "level or molecule data is null!";
         return QString();
     }
 
     return m_levelData->molecule()->moleculeName();
 }
 
-#include "playfield.moc"
+
